from setuptools import setup

setup(
    name='bianyi_package',
    version='0.1',
    description='A package to increment numbers by 1',
    # url='https://example.com',
    author='Lin p',
    author_email='L_hp777@163.com',
    py_modules=['bianyi'],
)
